.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _presentation-performance:

Performance benchmarks
======================

Testing speedup
---------------

- Comparison of test execution times with and without hierarchical parallelism.

Scalability
-----------

- Performance on laptops vs. HPC systems.

Plugin overhead
---------------

- Minimal performance impact of extensible plugins.
